install_ecosystem_after_embedded_apply

Function install_ecosystem_after_embedded_apply 

pub fn install_ecosystem_after_embedded_apply(
    runner: &dyn ProcessRunner,
    install_dir: &Path,
    choice: EcosystemInstallChoice,
) -> Result<Option<String>>
Resolve local bins and install selected ecosystem services after embedded full apply.

Errors

Returns crate::HortoError when bins cannot be resolved or install fails.